@@ -1,16 +1,10 @@
+mod candle_set;
 mod chart;
-use chart::*;
-
-mod chart_renderer;
-use chart_renderer::*;
-
-mod y_axis;
-use y_axis::*;
-
 mod chart_data;
-use chart_data::*;
-
+mod chart_renderer;
 mod info_bar;
+mod y_axis;
 
 pub use chart::Candle;
+pub use chart::CandleType;
 pub use chart::Chart;
